@@ -23,13 +23,13 @@
  * @author Akinobu Lee
  * @date   Fri Feb 16 13:42:28 2007
  *
- * $Revision: 1.3 $
+ * $Revision: 1.13 $
  * 
  */
 /*
- * Copyright (c) 1991-2007 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2012 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2007 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2012 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -209,11 +209,32 @@ typedef struct __jconf_am__ {
     char *ssload_filename;
   } frontend;
 
+  /**
+   * Plugin source ID when using plugin (gprune_method is GPRUNE_SEL_USER)
+   */
+  int gprune_plugin_source;
+
   /* pointer to next instance */
   struct __jconf_am__ *next;
 
 } JCONF_AM;
 
+/**
+ * Name lister for language model configurations
+ * 
+ */
+typedef struct __jconf_lm_namelist__ {
+  /**
+   * Entry name
+   */
+  char *name;
+  /**
+   * Pointer to next object
+   */
+  struct __jconf_lm_namelist__ *next;
+
+} JCONF_LM_NAMELIST;
+
 /**
  * Language models (N-gram / DFA), dictionary, and related parameters.
  * 
@@ -329,6 +350,21 @@ typedef struct __jconf_lm__ {
    */
   char wordrecog_silence_context_name[MAX_HMMNAME_LEN];
 
+  /**
+   * Name string of Unknown word for N-gram
+   */
+  char unknown_name[UNK_WORD_MAXLEN];
+
+  /**
+   * List of additional dictionary files
+   */
+  JCONF_LM_NAMELIST *additional_dict_files;
+
+  /**
+   * List of additional dictionary entries
+   */
+  JCONF_LM_NAMELIST *additional_dict_entries;
+
   /**
    * Pointer to next instance
    * 
@@ -434,11 +470,20 @@ typedef struct __jconf_search__ {
    */
   struct {
     /**
-     * Beam width of 1st pass. If value is -1 (not specified), system
-     * will guess the value from dictionary size.  If 0, a possible
-     * maximum value will be assigned to do full search.
+     * Beam width of rank pruning for the 1st pass. If value is -1
+     * (not specified), system will guess the value from dictionary
+     * size.  If 0, a possible maximum value will be assigned to do
+     * full search.
      */
     int specified_trellis_beam_width;
+
+#ifdef SCORE_PRUNING
+    /**
+     * Another beam width for score pruning at the 1st pass. If value
+     * is -1, or not specified, score pruning will be disabled.
+     */
+#endif
+    LOGPROB score_pruning_width;
     
 #if defined(WPAIR) && defined(WPAIR_KEEP_NLIMIT)
     /**
@@ -762,11 +807,30 @@ typedef struct __Jconf__ {
    */
   struct {
 
+    /**
+     * Input source type. (waveform / mfc)
+     * 
+     */
+    int type;
+
     /**
      * Input source.
      * 
      */
     int speech_input;
+
+    /**
+     * Input device.
+     * 
+     */
+    int device;
+
+    /**
+     * id of the selected plug-in if using plugin
+     * 
+     */
+    int plugin_source;
+
     /**
      * Sampling frequency
      * 
@@ -840,6 +904,12 @@ typedef struct __Jconf__ {
      * (-cutsilence / -nocutsilence)
      */
     int silence_cut;
+    /**
+     * Chunk size in samples, i.e. processing unit for audio input
+     * detection.  Segmentation will be done by this unit.
+     * 
+     */
+    int chunk_size;
 #ifdef GMM_VAD
     /**
      * (GMM_VAD) Backstep margin when speech trigger is detected.
@@ -992,8 +1062,30 @@ typedef struct __Jconf__ {
    */
   JCONF_AM *gmm;
 
+  /**
+   * Current option declaration mode while loading options
+   * 
+   */
+  short optsection;
+
+  /**
+   * Whether option sectioning ristriction should be applied or not
+   * 
+   */
+  boolean optsectioning;
+
+
 } Jconf;
 
+enum {
+  JCONF_OPT_DEFAULT,
+  JCONF_OPT_GLOBAL,
+  JCONF_OPT_AM,
+  JCONF_OPT_LM,
+  JCONF_OPT_SR,
+  SIZEOF_JCONF_OPT
+};
+
 #endif /* __J_JCONF_H__ */
 
 /*
