@@ -21,13 +21,13 @@
  * @author Akinobu LEE
  * @date   Thu Feb 10 14:54:06 2005
  *
- * $Revision: 1.2 $
+ * $Revision: 1.5 $
  *
  */
 /*
- * Copyright (c) 1991-2007 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2012 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2007 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2012 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -98,6 +98,10 @@ typedef struct _seg_token {
   struct _seg_token *list;	///< Link to next token, NULL if last
 } SEGTOKEN;
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /* mkwhmm.c */
 HMM *new_make_word_hmm(HTK_HMM_INFO *, HMM_Logical  **, int, boolean *);
 HMM *new_make_word_hmm_with_lm(HTK_HMM_INFO *, HMM_Logical  **, int, boolean *, LOGPROB *);
@@ -112,4 +116,8 @@ void put_hmm_arc(FILE *fp, HMM *d);
 void put_hmm_outprob(FILE *fp, HMM *d);
 void put_hmm(FILE *fp, HMM *d);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* __SENT_HMM_NEW2_H__ */
