@@ -1,7 +1,5 @@
 /**
  * @file   htk_param.h
- * @author Akinobu LEE
- * @date   Fri Feb 11 02:52:52 2005
  *
  * <EN>
  * @brief Structures for storing input speech parameters
@@ -47,13 +45,16 @@
  *
  * @sa htk_defs.h
  *
- * $Revision: 1.2 $
+ * @author Akinobu LEE
+ * @date   Fri Feb 11 02:52:52 2005
+ *
+ * $Revision: 1.5 $
  * 
  */
 /*
- * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2012 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2012 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -77,9 +78,21 @@ typedef struct {
   unsigned int samplenum;	///< Number of sample (same in header.samplenum) 
   short veclen;			///< Vector length of a sample
   VECT **parvec;		///< Actual parameter vectors [0..samplenum-1][0..veclen-1]
+  short veclen_alloc;		///< Allocated vector length of a sample
+  unsigned int samplenum_alloc;	///< Alllocated number of samples
+  BMALLOC_BASE *mroot;		///< Pointer for block memory allocation
 } HTK_Param;
 
-
+/**
+ * Increment step of HTK Parameter holder in frames
+ * 
+ */
+#define HTK_PARAM_INCREMENT_STEP_FRAME 200
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 boolean rdparam(char *, HTK_Param *);
 HTK_Param *new_param();
 void free_param(HTK_Param *);
@@ -87,17 +100,22 @@ short param_qualstr2code(char *);
 short param_str2code(char *);
 char *param_qualcode2str(char *, short, boolean);
 char *param_code2str(char *, short, boolean);
-HTK_Param *new_select_param_kind(HTK_Param *src, short select_qualifier);
-boolean select_param_vmark(HTK_Param *src, short dst_type);
-int exec_exclude_one_vector(VECT *vec, int len);
 int guess_basenum(HTK_Param *p, short qualtype);
 boolean param_strip_zero(HTK_Param *param);
 
+void param_init_content(HTK_Param *p);
+boolean param_alloc(HTK_Param *p, unsigned int samplenum, short veclen);
+void param_free_content(HTK_Param *p);
+
 
 /* hmminfo/put_htkdata_info.c */
-void put_param_head(HTK_Param_Header *h);
-void put_vec(VECT **p, int num, short veclen);
-void put_param(HTK_Param *pinfo);
-void put_param_info(HTK_Param *pinfo);
+void put_param_head(FILE *fp, HTK_Param_Header *h);
+void put_vec(FILE *fp, VECT **p, int num, short veclen);
+void put_param(FILE *fp, HTK_Param *pinfo);
+void put_param_info(FILE *fp, HTK_Param *pinfo);
+
+#ifdef __cplusplus
+}
+#endif
 
 #endif /* __SENT_HTK_PARAM_H__ */
