@@ -1,7 +1,5 @@
 /**
  * @file   stddefs.h
- * @author Akinobu LEE
- * @date   Sat Feb 12 11:49:37 2005
  *
  * <EN>
  * @brief  Basic common definitions
@@ -28,13 +26,16 @@
  *
  * @sa machines.h
  * 
- * $Revision: 1.3 $
+ * @author Akinobu LEE
+ * @date   Sat Feb 12 11:49:37 2005
+ *
+ * $Revision: 1.8 $
  * 
  */
 /*
- * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2012 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2012 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -43,14 +44,13 @@
 
 /* load site-dependent configuration by configure script */
 #if defined(_WIN32) && !defined(__CYGWIN32__) && !defined(__MINGW32__)
-#include <sent/config-win.h>
+#include <config-msvc-libsent.h>
 #else
 #include <sent/config.h>
 #endif
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <strings.h>
 #include <string.h>
 #include <math.h>
 #if !defined(_WIN32) || defined(__CYGWIN32__) || defined(__MINGW32__)
@@ -63,7 +63,16 @@
 #else
 /* win32 */
 #include <io.h>
-#define sleep(x) Sleep(x)
+#endif
+
+/* get around sleep() */
+#ifdef _WIN32
+# if !defined(__CYGWIN32__) && !defined(__MINGW32__)
+# define sleep(x) Sleep(x)
+# endif
+# ifndef HAVE_SLEEP
+# define sleep(x) Sleep(x)
+# endif
 #endif
 
 #include <errno.h>
@@ -84,9 +93,11 @@
 #if !defined(LOGTPI)
 #define LOGTPI 1.83787706640935
 #endif
-/// Static log_e(10)
 #if !defined(LOG_TEN)
+/// Static log_e(10)
 #define LOG_TEN 2.30258509
+/// Static 1 / LOG_TEN
+#define INV_LOG_TEN .434294482
 #endif
 
 /// Boolean type
@@ -102,7 +113,6 @@ typedef unsigned char boolean;
 #define close _close
 #define eof _eof
 #define filelength _filelength
-#define isatty _isatty
 #define lseek _lseek
 #define open _open
 #define read _read
@@ -113,10 +123,7 @@ typedef unsigned char boolean;
 #define getpid _getpid
 #define vsnprintf _vsnprintf
 #define snprintf _snprintf
-#endif
-/* get around sleep() missing in mingw */
-#if defined(_WIN32) && !defined(HAVE_SLEEP)
-#define sleep _sleep
+#define strdup _strdup
 #endif
 
 #ifndef R_OK
@@ -194,6 +201,11 @@ typedef unsigned short WORD_ID; ///< Typedef for word ID
 /// Assumed maximum number of bytes per input line
 #define MAXLINELEN 1024
 
+/// Limit of maximum length of a file path
+#ifndef MAXPATHLEN
+#define MAXPATHLEN 2048
+#endif
+
 #include <sent/util.h>
 
 #endif /* __SENT_STANDARD_DEFS__ */
