@@ -56,13 +56,13 @@
  * @author Akinobu LEE
  * @date   Sun Feb 13 13:31:20 2005
  *
- * $Revision: 1.5 $
+ * $Revision: 1.10 $
  * 
  */
 /*
- * Copyright (c) 1991-2007 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2012 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2007 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2012 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -350,13 +350,26 @@ adin_file_standby(int freq, void *arg)
  * will be read from the listfile.  Otherwise, the
  * filename will be obtained from stdin.  Then the file will be opened here.
  * 
+ * @param filename [in] file name to open or NULL for prompt
+ * 
  * @return TRUE on success, FALSE on failure.
  */
 boolean
-adin_file_begin()
+adin_file_begin(char *filename)
 {
   boolean readp;
 
+  if (filename != NULL) {
+    /* open the file and exit with its status */
+    if (adin_file_open(filename) == FALSE) {
+      jlog("Error: adin_file: failed to read speech data: \"%s\"\n", filename);
+      return FALSE;
+    }
+    jlog("Stat: adin_file: input speechfile: %s\n", filename);
+    strcpy(speechfilename, filename);
+    return TRUE;
+  }
+
   /* ready to read next input */
   readp = FALSE;
   while(readp == FALSE) {
@@ -483,10 +496,12 @@ adin_stdin_standby(int freq, void *arg)
 /** 
  * @brief  Begin reading audio data from stdin
  *
+ * @param pathname [in] dummy
+ *
  * @return TRUE on success, FALSE on failure.
  */
 boolean
-adin_stdin_begin()
+adin_stdin_begin(char *pathname)
 {
   if (feof(stdin)) {		/* already reached the end of input stream */
     jlog("Error: adin_stdin: stdin reached EOF\n");
@@ -516,7 +531,7 @@ adin_stdin_read(SP16 *buf, int sampnum)
   int cnt;
 
   if (wav_p) {
-    cnt = myfread(buf, sizeof(SP16), sampnum, stdin);
+    cnt = fread(buf, sizeof(SP16), sampnum, stdin);
     if (cnt == 0) {
       if (feof(stdin)) return -1; /* EOF */
       if (ferror(stdin)) {
@@ -571,3 +586,15 @@ adin_file_get_current_filename()
 {
   return(speechfilename);
 }
+/** 
+ * 
+ * A tiny function to get current input raw speech file name.
+ * 
+ * @return string of current input speech file.
+ * 
+ */
+char *
+adin_stdin_input_name()
+{
+  return("stdin");
+}
