@@ -29,7 +29,7 @@
  * @author Masatomo Hashimoto
  * @date   Wed Oct 12 11:31:27 2005
  *
- * $Revision: 1.2 $
+ * $Revision: 1.6 $
  * 
  */
 
@@ -44,12 +44,13 @@
  *
  */
 
-/* $Id: adin_mic_darwin_coreaudio.c,v 1.2 2007/12/18 08:45:50 sumomo Exp $ */
+/* $Id: adin_mic_darwin_coreaudio.c,v 1.6 2009/12/08 01:49:21 sumomo Exp $ */
 
 #include <CoreAudio/CoreAudio.h>
 #include <AudioUnit/AudioUnit.h>
 #include <AudioUnit/AudioOutputUnit.h>
 #include <AudioToolbox/AudioConverter.h>
+#include <CoreServices/CoreServices.h>
 #include <pthread.h>
 #include <stdio.h>
 
@@ -88,6 +89,8 @@ static AudioBufferList* BufList;
 static AudioBufferList BufListBackup;
 static AudioBufferList* BufListConverted;
 
+static char deviceName[DEVICE_NAME_LEN];
+
 #ifndef boolean
 typedef unsigned char boolean;
 #endif
@@ -285,7 +288,6 @@ InputProc(void* inRefCon,
 boolean adin_mic_standby(int sfreq, void* dummy) {
   OSStatus status;
   UInt32 propertySize;
-  char deviceName[DEVICE_NAME_LEN];
   struct AudioStreamBasicDescription inDesc;
   int err;
 
@@ -294,9 +296,14 @@ boolean adin_mic_standby(int sfreq, void* dummy) {
   if (CoreAudioInit) 
     return TRUE;
 
+#ifdef MAC_OS_X_VERSION_10_6
+  AudioComponent halout;
+  AudioComponentDescription haloutDesc;
+#else
   Component halout;
   ComponentDescription haloutDesc;
-
+#endif
+   
   haloutDesc.componentType = kAudioUnitType_Output;
   haloutDesc.componentSubType = kAudioUnitSubType_HALOutput;
   haloutDesc.componentManufacturer = kAudioUnitManufacturer_Apple;
@@ -568,7 +575,7 @@ boolean adin_mic_standby(int sfreq, void* dummy) {
   return TRUE;
 }
 
-boolean adin_mic_begin(){ return TRUE; }
+boolean adin_mic_begin(char *pathname){ return TRUE; }
 boolean adin_mic_end(){ return TRUE; }
 
 int adin_mic_read(void *buffer, int nsamples) {
@@ -656,3 +663,16 @@ void adin_mic_pause() {
   }
   return;
 }
+
+/** 
+ * 
+ * Function to return current input source device name
+ * 
+ * @return string of current input device name.
+ * 
+ */
+char *
+adin_mic_input_name()
+{
+  return(deviceName);
+}
