@@ -47,12 +47,13 @@
  *   - adin_terminate()
  *   - adin_pause()
  *   - adin_resume()
+ *   - adin_input_name()
  * 
  * 
  * @author Akinobu Lee
  * @date   Thu Aug  7 14:28:37 2008
  * 
- * $Revision: 1.1 $
+ * $Revision: 1.3 $
  * 
  */
 
@@ -420,6 +421,8 @@ adin_standby(int sfreq, void *dummy)
  * If this function returns FALSE, Julius will exit recognition loop.
  * 
  * JuliusLib: this will be called at j_open_stream().
+ *
+ * @param pathname [in] file / device name to open or NULL for default
  * 
  * @return TRUE on success, FALSE on failure.
  * </EN>
@@ -433,11 +436,13 @@ adin_standby(int sfreq, void *dummy)
  * 
  * JuliusLib: δؿ j_open_stream() ǸƤФ롥
  * 
+ * @param pathname [in] ե뤢뤤ϥǥХ̾NULL ʤǥե
+ * 
  * @return  TRUEԻ FALSE ֤
  * </JA>
  */
 boolean
-adin_open()
+adin_open(char *pathname)
 {
   /* do open the device */
   int fmt;
@@ -446,8 +451,8 @@ adin_open()
   int s;
   char buf[2];
 
-  if ((audio_fd = open("/dev/dsp", O_RDONLY)) == -1) {
-    printf("Error: cannot open /dev/dsp\n");
+  if ((audio_fd = open(pathname ? pathname : "/dev/dsp", O_RDONLY)) == -1) {
+    printf("Error: cannot open %s\n", pathname ? pathname : "/dev/dsp");
     return FALSE;
   }
   fmt = AFMT_S16_LE;               /* 16bit signed (little endian) */
@@ -802,4 +807,27 @@ adin_resume()
   return TRUE;
 }
 
+/**
+ * <EN>
+ * @brief  A function to return current device name for information (optional)
+ *
+ * This function is totally optional.
+ * 
+ * @return pointer to the device name string
+ * </EN>
+ * <JA>
+ * @brief  ϥե롦ǥХ֤̾ؿǤա
+ *
+ * @return ϥե뤢뤤ϥǥХ̾ʸؤΥݥ
+ * </JA>
+ * 
+ */
+char *
+adin_input_name()
+{
+  printf("input name function was called\n");
+  return("default");
+}
+
+
 /* end of file */
