@@ -9,9 +9,15 @@ if [[ $# == 0 ]]; then
 fi
 newver=$1
 
-for i in ./julius/configure.in ./libsent/configure.in ./configure.in ./support/build-all.sh; do
+for i in ./libjulius/configure.in ./support/build-all.sh; do
 	echo $i
-	sed -e "s/^VERSION=[^ ]*/VERSION=$newver/" < $i > tmp
+	sed -e "s/^JULIUS_VERSION=[^ ]*/JULIUS_VERSION=$newver/" < $i > tmp
+	diff $i tmp
+	mv tmp ${i}
+done
+for i in ./libsent/configure.in; do
+	echo $i
+	sed -e "s/^LIBSENT_VERSION=[^ ]*/LIBSENT_VERSION=$newver/" < $i > tmp
 	diff $i tmp
 	mv tmp ${i}
 done
@@ -20,4 +26,4 @@ echo
 echo updating configure scripts...
 cd ./julius; autoconf
 cd ../libsent; autoconf
-cd ..; autoconf
+cd ../libjulius; autoconf
